@@ -48,7 +48,7 @@ Options to get the internal password representation:
 
 Options to use the internal password representation:
  -k, --keys <X> <Y> <Z>      Internal password representation as three 32-bits
-                              integers in hexadecimal (requires -d, -U,
+                              integers in hexadecimal (requires -d, -D, -U,
                               --change-keys or --bruteforce)
 
  -d, --decipher <file>       File to write the deciphered data (requires -c)
@@ -334,7 +334,7 @@ try
 
                 std::cout << "You may resume the password recovery with the option: --continue-recovery ";
                 for (const auto c : restart)
-                    std::cout << std::setw(2) << static_cast<int>(c);
+                    std::cout << std::setw(2) << int{static_cast<std::uint8_t>(c)};
                 std::cout << std::endl;
 
                 std::cout.fill(fillBefore);
@@ -357,9 +357,9 @@ try
 
             for (const auto& password : passwords)
             {
-                std::cout << "as bytes: ";
+                std::cout << "as bytes:";
                 for (const auto c : password)
-                    std::cout << std::setw(2) << static_cast<int>(c) << ' ';
+                    std::cout << ' ' << std::setw(2) << int{static_cast<std::uint8_t>(c)};
                 std::cout << std::endl;
                 std::cout << "as text: " << password << std::endl;
             }
